==> react-nlp-annotate-0.1.11.tgz: package/components/Document/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from "react";
import { makeStyles } from "@material-ui/styles";
import stringToSequence from "../../string-to-sequence.js";
var useStyles = makeStyles({});
export default function Document(_ref) {
  var sequence = _ref.sequence,
      _ref$onHighlightedCha = _ref.onHighlightedChanged,
      onHighlightedChanged = _ref$onHighlightedCha === void 0 ? function () {
    return null;
  } : _ref$onHighlightedCha,
      _ref$onSequenceChange = _ref.onSequenceChange,
      onSequenceChange = _ref$onSequenceChange === void 0 ? function () {
    return null;
  } : _ref$onSequenceChange,
      nothingHighlighted = _ref.nothingHighlighted,
      _ref$colorLabelMap = _ref.colorLabelMap,
      colorLabelMap = _ref$colorLabelMap === void 0 ? {} : _ref$colorLabelMap;

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      mouseDown = _useState2[0],
      changeMouseDown = _useState2[1];

  var _useState3 = useState([null, null]),
      _useState4 = _slicedToArray(_useState3, 2),
      _useState4$ = _slicedToArray(_useState4[0], 2),
      firstSelected = _useState4$[0],
      lastSelected = _useState4$[1],
      changeHighlightedRangeState = _useState4[1];

  var changeHighlightedRange = function changeHighlightedRange(_ref2) {
    var _ref3 = _slicedToArray(_ref2, 2),
        first = _ref3[0],
        last = _ref3[1];

    changeHighlightedRangeState([first, last]);
    var highlightedItems = [];

    for (var i = Math.min(first, last); i <= Math.max(first, last); i++) {
      highlightedItems.push(i);
    }

    onHighlightedChanged(highlightedItems);
  };

  var highlightedItems = [];

  if (!nothingHighlighted && firstSelected !== null && lastSelected !== null) {
    for (var i = Math.min(firstSelected, lastSelected); i <= Math.max(firstSelected, lastSelected); i++) {
      highlightedItems.push(i);
    }
  }

  return React.createElement("div", {
    onMouseDown: function onMouseDown() {
      return changeMouseDown(true);
    },
    onMouseUp: function onMouseUp() {
      return changeMouseDown(false);
    }
  }, sequence.map(function (seq, i) {
    return React.createElement(React.Fragment, null, React.createElement("span", {
      onMouseDown: function onMouseDown() {
        if (seq.label) return;
        changeHighlightedRange([i, i]);
      },
      onMouseMove: function onMouseMove() {
        if (seq.label) return;

        if (mouseDown && i !== lastSelected) {
          changeHighlightedRange([firstSelected === null ? i : firstSelected, i]);
        }
      },
      style: seq.label ? {
        display: "inline-flex",
        backgroundColor: seq.color || colorLabelMap[seq.label] || "#333",
        color: "#fff",
        padding: 4,
        margin: 4,
        paddingLeft: 10,
        paddingRight: 10,
        borderRadius: 4,
        userSelect: "none"
      } : {
        display: "inline-flex",
        backgroundColor: seq.text !== " " && highlightedItems.includes(i) ? "#ccc" : "inherit",
        color: "#333",
        marginTop: 4,
        marginBottom: 4,
        paddingTop: 4,
        paddingBottom: 4,
        paddingLeft: 2,
        paddingRight: 2,
        userSelect: "none"
      },
      key: i
    }, React.createElement("div", null, seq.text), seq.label && React.createElement("div", {
      onClick: function onClick() {
        onSequenceChange(sequence.flatMap(function (s) {
          return s !== seq ? s : stringToSequence(s.text);
        }).filter(function (s) {
          return s.text.length > 0;
        }));
      },
      style: {
        display: "inline-flex",
        cursor: "pointer",
        alignSelf: "center",
        fontSize: 11,
        width: 18,
        height: 18,
        alignItems: "center",
        justifyContent: "center",
        marginLeft: 4,
        borderRadius: 9,
        color: "#fff",
        backgroundColor: "rgba(0,0,0,0.2)"
      }
    }, React.createElement("span", null, "\u2716"))));
  }));
}

==> react-nlp-annotate-0.1.17.tgz: package/components/Document/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from "react";
import { makeStyles } from "@material-ui/styles";
import stringToSequence from "../../string-to-sequence.js";
import Tooltip from "@material-ui/core/Tooltip";
var useStyles = makeStyles({});
export default function Document(_ref) {
  var sequence = _ref.sequence,
      _ref$onHighlightedCha = _ref.onHighlightedChanged,
      onHighlightedChanged = _ref$onHighlightedCha === void 0 ? function () {
    return null;
  } : _ref$onHighlightedCha,
      _ref$onSequenceChange = _ref.onSequenceChange,
      onSequenceChange = _ref$onSequenceChange === void 0 ? function () {
    return null;
  } : _ref$onSequenceChange,
      nothingHighlighted = _ref.nothingHighlighted,
      _ref$colorLabelMap = _ref.colorLabelMap,
      colorLabelMap = _ref$colorLabelMap === void 0 ? {} : _ref$colorLabelMap;

  var _useState = useState(),
      _useState2 = _slicedToArray(_useState, 2),
      mouseDown = _useState2[0],
      changeMouseDown = _useState2[1];

  var _useState3 = useState([null, null]),
      _useState4 = _slicedToArray(_useState3, 2),
      _useState4$ = _slicedToArray(_useState4[0], 2),
      firstSelected = _useState4$[0],
      lastSelected = _useState4$[1],
      changeHighlightedRangeState = _useState4[1];

  var changeHighlightedRange = function changeHighlightedRange(_ref2) {
    var _ref3 = _slicedToArray(_ref2, 2),
        first = _ref3[0],
        last = _ref3[1];

    changeHighlightedRangeState([first, last]);
    var highlightedItems = [];

    for (var i = Math.min(first, last); i <= Math.max(first, last); i++) {
      highlightedItems.push(i);
    }

    onHighlightedChanged(highlightedItems);
  };

  var highlightedItems = [];

  if (!nothingHighlighted && firstSelected !== null && lastSelected !== null) {
    for (var i = Math.min(firstSelected, lastSelected); i <= Math.max(firstSelected, lastSelected); i++) {
      highlightedItems.push(i);
    }
  }

  return React.createElement("div", {
    onMouseDown: function onMouseDown() {
      return changeMouseDown(true);
    },
    onMouseUp: function onMouseUp() {
      return changeMouseDown(false);
    }
  }, sequence.map(function (seq, i) {
    return React.createElement(React.Fragment, null, React.createElement("span", {
      onMouseDown: function onMouseDown() {
        if (seq.label) return;
        changeHighlightedRange([i, i]);
      },
      onMouseMove: function onMouseMove() {
        if (seq.label) return;

        if (mouseDown && i !== lastSelected) {
          changeHighlightedRange([firstSelected === null ? i : firstSelected, i]);
        }
      },
      style: seq.label ? {
        display: "inline-flex",
        backgroundColor: seq.color || colorLabelMap[seq.label] || "#333",
        color: "#fff",
        padding: 4,
        margin: 4,
        paddingLeft: 10,
        paddingRight: 10,
        borderRadius: 4,
        userSelect: "none"
      } : {
        display: "inline-flex",
        backgroundColor: seq.text !== " " && highlightedItems.includes(i) ? "#ccc" : "inherit",
        color: "#333",
        marginTop: 4,
        marginBottom: 4,
        paddingTop: 4,
        paddingBottom: 4,
        paddingLeft: 2,
        paddingRight: 2,
        userSelect: "none"
      },
      key: i
    }, seq.label ? React.createElement(Tooltip, {
      title: seq.label,
      placement: "bottom"
    }, React.createElement("div", null, seq.text)) : React.createElement("div", null, seq.text), seq.label && React.createElement("div", {
      onClick: function onClick() {
        onSequenceChange(sequence.flatMap(function (s) {
          return s !== seq ? s : stringToSequence(s.text);
        }).filter(function (s) {
          return s.text.length > 0;
        }));
      },
      style: {
        display: "inline-flex",
        cursor: "pointer",
        alignSelf: "center",
        fontSize: 11,
        width: 18,
        height: 18,
        alignItems: "center",
        justifyContent: "center",
        marginLeft: 4,
        borderRadius: 9,
        color: "#fff",
        backgroundColor: "rgba(0,0,0,0.2)"
      }
    }, React.createElement("span", null, "\u2716"))));
  }));
}
